==> vue-dropdown-3.22.1.tgz: package/lib/mobile-first.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { createVNode, resolveComponent, withDirectives, resolveDirective } from "vue";
import { api, renderless } from "@opentinyvue/vue-renderless/dropdown/vue";
import { defineComponent, $props, directive, setup as _setup, h, $prefix } from "@opentinyvue/vue-common";
import Button from "@opentinyvue/vue-button";
import ButtonGroup from "@opentinyvue/vue-button-group";
import { Clickoutside } from "@opentinyvue/vue-directive";
import { IconArrowBottom, IconChevronUp, IconChevronDown } from "@opentinyvue/vue-icon";
var _sfc_main = /* @__PURE__ */ defineComponent({
  name: $prefix + "Dropdown",
  componentName: "TinyDropdown",
  components: {
    TinyButton: Button,
    TinyButtonGroup: ButtonGroup,
    IconChevronDown: IconChevronDown(),
    IconChevronUp: IconChevronUp(),
    IconArrowBottom: IconArrowBottom()
  },
  directives: directive({
    Clickoutside
  }),
  props: _extends({}, $props, {
    type: String,
    trigger: String,
    size: {
      type: String,
      default: ""
    },
    disabled: {
      type: Boolean,
      default: false
    },
    singleButton: {
      type: Boolean,
      default: false
    },
    showTimeout: {
      type: Number,
      default: 250
    },
    hideTimeout: {
      type: Number,
      default: 150
    },
    hideOnClick: {
      type: Boolean,
      default: true
    },
    tabindex: {
      type: Number,
      default: 0
    },
    border: {
      type: Boolean,
      default: false
    },
    round: {
      type: Boolean,
      default: false
    },
    showIcon: {
      type: Boolean,
      default: true
    },
    modelValue: [String, Number],
    showSelfIcon: {
      type: Boolean,
      default: false
    },
    lazyShowPopper: {
      type: Boolean,
      default: false
    }
  }),
  emits: ["visible-change", "item-click", "button-click", "current-item-click", "menu-item-click", "is-disabled", "selected-index"],
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      h
    });
  },
  render: function render() {
    var type = this.type, disabled = this.disabled, handleMainButtonClick = this.handleMainButtonClick, slots = this.slots, size = this.size, state = this.state, border = this.border, round = this.round, m = this.m, clickOutside = this.clickOutside, singleButton = this.singleButton;
    var params = {
      visible: state.visible
    };
    var triggerElm = null;
    if (singleButton) {
      triggerElm = createVNode(resolveComponent("tiny-button"), {
        "ref": "trigger",
        "type": type === "primary" ? type : "",
        "size": size,
        "customClass": m(["rounded active:rounded flex items-center justify-center", state.visible && type !== "primary" && "active:border-color-border-focus text-color-text-primary active:text-color-brand-focus focus:border-color-border-focus focus:text-color-brand-focus"]),
        "disabled": disabled,
        "reset-time": 0,
        "onClick": handleMainButtonClick
      }, {
        default: function _default() {
          return [createVNode("div", {
            "class": "overflow-hidden overflow-ellipsis whitespace-nowrap w-full"
          }, [slots.default && slots.default(params)])];
        }
      });
    } else {
      var defaultSlot = slots.default && slots.default(params);
      var suffixSlot = slots["suffix-icon"] && slots["suffix-icon"]();
      var vnodeData = (defaultSlot == null ? void 0 : defaultSlot[0].data) || {};
      var _vnodeData$attrs = vnodeData.attrs, attrs = _vnodeData$attrs === void 0 ? {} : _vnodeData$attrs;
      if (disabled && !attrs.disabled) {
        attrs.disabled = true;
        vnodeData.attrs = attrs;
      }
      var defaultIcon = createVNode("span", {
        "class": "block text-[0]"
      }, [createVNode(resolveComponent("icon-chevron-down"), {
        "class": "sm:block hidden will-change-transform"
      }, null), createVNode(resolveComponent("icon-arrow-bottom"), {
        "class": "sm:hidden block will-change-transform"
      }, null)]);
      var suffixInner = state.showIcon && createVNode("span", {
        "data-tag": "tiny-dropdown-showicon",
        "class": ["ml-1 sm:ml-2 [&_svg:nth-of-type(1)]:align-top w-4 h-4 inline-block [&_svg]:transition-transform [&_svg]:duration-300", {
          "fill-color-brand-focus [&_svg:nth-of-type(1)]:hover:fill-color-brand-hover [&_svg:nth-of-type(1)]:active:fill-color-brand-focus leading-4": !disabled && !border
        }, border && (state.visible ? "[&_svg]:rotate-180" : "[&_svg]:rotate-0"), border && type !== "primary" && state.visible && "[&_svg]:fill-color-border-focus visited:[&_svg]:fill-color-border-focus active:[&_svg]:fill-color-border-focus"]
      }, [suffixSlot || defaultIcon]);
      triggerElm = border ? createVNode(resolveComponent("tiny-button"), {
        "ref": "trigger",
        "round": round,
        "size": size,
        "type": type === "primary" ? type : "",
        "disabled": disabled,
        "class": ["rounded inline-flex items-center justify-center", type === "primary" ? "[&_svg]:fill-color-bg-1" : state.visible ? "active:border-color-border-focus text-color-text-primary active:text-color-brand-focus focus:border-color-border-focus focus:text-color-brand-focus" : "[&_svg]:fill-color-icon-placeholder"],
        "reset-time": 0
      }, {
        default: function _default() {
          return [defaultSlot, suffixInner];
        }
      }) : createVNode("span", {
        "ref": "trigger",
        "class": [state.visible && !state.showSelfIcon ? "[&_svg]:rotate-180" : "[&_svg]:rotate-0", disabled && "cursor-not-allowed [&_svg]:fill-color-text-disabled", "inline-flex [&_svg]:transition-transform [&_svg]:duration-300"]
      }, [createVNode("span", {
        "class": ["inline-flex h-4 leading-4", disabled ? "text-color-text-disabled" : "hover:text-color-brand-hover active:text-color-brand-focus"]
      }, [defaultSlot]), createVNode("span", {
        "class": "align-bottom leading-4 h-4"
      }, [suffixInner])]);
    }
    var menuElm = disabled ? null : slots.dropdown && slots.dropdown();
    return withDirectives(createVNode("div", {
      "class": ["relative inline-block [&>span:nth-of-type(1)]:text-color-brand-focus [&>span:nth-of-type(1)]:text-sm sm:[&>span:nth-of-type(1)]:text-xs", disabled && "[&>span:nth-of-type(1)]:text-color-brand-focus", state.showSelfIcon && "leading-4 h-4 [&_svg]:align-top [&_svg]:rotate-0"],
      "aria-disabled": disabled,
      "data-tag": "tiny-dropdown"
    }, [triggerElm, menuElm]), [[resolveDirective("clickoutside"), clickOutside]]);
  }
});
export {
  _sfc_main as default
};

==> vue-dropdown-3.24.0.tgz: package/lib/mobile-first.js <==
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import { createVNode, resolveComponent, withDirectives, resolveDirective } from "vue";
import { api, renderless } from "@opentiny/vue-renderless/dropdown/vue";
import { defineComponent, $props, directive, setup as _setup, h, $prefix } from "@opentiny/vue-common";
import Button from "@opentiny/vue-button";
import ButtonGroup from "@opentiny/vue-button-group";
import { Clickoutside } from "@opentiny/vue-directive";
import { IconArrowBottom, IconChevronUp, IconChevronDown } from "@opentiny/vue-icon";
var _sfc_main = /* @__PURE__ */ defineComponent({
  name: $prefix + "Dropdown",
  componentName: "TinyDropdown",
  components: {
    TinyButton: Button,
    TinyButtonGroup: ButtonGroup,
    IconChevronDown: IconChevronDown(),
    IconChevronUp: IconChevronUp(),
    IconArrowBottom: IconArrowBottom()
  },
  directives: directive({
    Clickoutside
  }),
  props: _extends({}, $props, {
    type: String,
    trigger: String,
    size: {
      type: String,
      default: ""
    },
    disabled: {
      type: Boolean,
      default: false
    },
    singleButton: {
      type: Boolean,
      default: false
    },
    showTimeout: {
      type: Number,
      default: 250
    },
    hideTimeout: {
      type: Number,
      default: 150
    },
    hideOnClick: {
      type: Boolean,
      default: true
    },
    tabindex: {
      type: Number,
      default: 0
    },
    border: {
      type: Boolean,
      default: false
    },
    round: {
      type: Boolean,
      default: false
    },
    showIcon: {
      type: Boolean,
      default: true
    },
    modelValue: [String, Number],
    showSelfIcon: {
      type: Boolean,
      default: false
    },
    lazyShowPopper: {
      type: Boolean,
      default: false
    }
  }),
  emits: ["visible-change", "item-click", "button-click", "current-item-click", "menu-item-click", "is-disabled", "selected-index"],
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api,
      mono: true,
      h
    });
  },
  render: function render() {
    var type = this.type, disabled = this.disabled, handleMainButtonClick = this.handleMainButtonClick, slots = this.slots, size = this.size, state = this.state, border = this.border, round = this.round, m = this.m, clickOutside = this.clickOutside, singleButton = this.singleButton;
    var params = {
      visible: state.visible
    };
    var triggerElm = null;
    if (singleButton) {
      triggerElm = createVNode(resolveComponent("tiny-button"), {
        "ref": "trigger",
        "type": type === "primary" ? type : "",
        "size": size,
        "customClass": m(["rounded active:rounded flex items-center justify-center", state.visible && type !== "primary" && "active:border-color-border-focus text-color-text-primary active:text-color-brand-focus focus:border-color-border-focus focus:text-color-brand-focus"]),
        "disabled": disabled,
        "reset-time": 0,
        "onClick": handleMainButtonClick
      }, {
        default: function _default() {
          return [createVNode("div", {
            "class": "overflow-hidden overflow-ellipsis whitespace-nowrap w-full"
          }, [slots.default && slots.default(params)])];
        }
      });
    } else {
      var defaultSlot = slots.default && slots.default(params);
      var suffixSlot = slots["suffix-icon"] && slots["suffix-icon"]();
      var vnodeData = (defaultSlot == null ? void 0 : defaultSlot[0].data) || {};
      var _vnodeData$attrs = vnodeData.attrs, attrs = _vnodeData$attrs === void 0 ? {} : _vnodeData$attrs;
      if (disabled && !attrs.disabled) {
        attrs.disabled = true;
        vnodeData.attrs = attrs;
      }
      var defaultIcon = createVNode("span", {
        "class": "block text-[0]"
      }, [createVNode(resolveComponent("icon-chevron-down"), {
        "class": "sm:block hidden will-change-transform"
      }, null), createVNode(resolveComponent("icon-arrow-bottom"), {
        "class": "sm:hidden block will-change-transform"
      }, null)]);
      var suffixInner = state.showIcon && createVNode("span", {
        "data-tag": "tiny-dropdown-showicon",
        "class": ["ml-1 sm:ml-2 [&_svg:nth-of-type(1)]:align-top w-4 h-4 inline-block [&_svg]:transition-transform [&_svg]:duration-300", {
          "fill-color-brand-focus [&_svg:nth-of-type(1)]:hover:fill-color-brand-hover [&_svg:nth-of-type(1)]:active:fill-color-brand-focus leading-4": !disabled && !border
        }, border && (state.visible ? "[&_svg]:rotate-180" : "[&_svg]:rotate-0"), border && type !== "primary" && state.visible && "[&_svg]:fill-color-border-focus visited:[&_svg]:fill-color-border-focus active:[&_svg]:fill-color-border-focus"]
      }, [suffixSlot || defaultIcon]);
      triggerElm = border ? createVNode(resolveComponent("tiny-button"), {
        "ref": "trigger",
        "round": round,
        "size": size,
        "type": type === "primary" ? type : "",
        "disabled": disabled,
        "class": ["rounded inline-flex items-center justify-center", type === "primary" ? "[&_svg]:fill-color-bg-1" : state.visible ? "active:border-color-border-focus text-color-text-primary active:text-color-brand-focus focus:border-color-border-focus focus:text-color-brand-focus" : "[&_svg]:fill-color-icon-placeholder"],
        "reset-time": 0
      }, {
        default: function _default() {
          return [defaultSlot, suffixInner];
        }
      }) : createVNode("span", {
        "ref": "trigger",
        "class": [state.visible && !state.showSelfIcon ? "[&_svg]:rotate-180" : "[&_svg]:rotate-0", disabled && "cursor-not-allowed [&_svg]:fill-color-text-disabled", "inline-flex [&_svg]:transition-transform [&_svg]:duration-300"]
      }, [createVNode("span", {
        "class": ["inline-flex h-4 leading-4", disabled ? "text-color-text-disabled" : "hover:text-color-brand-hover active:text-color-brand-focus"]
      }, [defaultSlot]), createVNode("span", {
        "class": "align-bottom leading-4 h-4"
      }, [suffixInner])]);
    }
    var menuElm = disabled ? null : slots.dropdown && slots.dropdown();
    return withDirectives(createVNode("div", {
      "class": ["relative inline-block [&>span:nth-of-type(1)]:text-color-brand-focus [&>span:nth-of-type(1)]:text-sm sm:[&>span:nth-of-type(1)]:text-xs", disabled && "[&>span:nth-of-type(1)]:text-color-brand-focus", state.showSelfIcon && "leading-4 h-4 [&_svg]:align-top [&_svg]:rotate-0"],
      "aria-disabled": disabled,
      "data-tag": "tiny-dropdown"
    }, [triggerElm, menuElm]), [[resolveDirective("clickoutside"), clickOutside]]);
  }
});
export {
  _sfc_main as default
};
